pub enum PictureCompositeMode {
MixBlend(MixBlendMode),
Filter(Filter),
ComponentTransferFilter(Handle<FilterDataIntern>),
Blit(BlitReason),
TileCache {
slice_id: SliceId,
},
SVGFEGraph(Vec<(FilterGraphNode, FilterGraphOp)>),
IntermediateSurface,
}Expand description
Specifies how this Picture should be composited onto the target it belongs to.
Variants
MixBlend(MixBlendMode)
Apply CSS mix-blend-mode effect.
Filter(Filter)
Apply a CSS filter (except component transfer).
ComponentTransferFilter(Handle<FilterDataIntern>)
Apply a component transfer filter.
Blit(BlitReason)
Draw to intermediate surface, copy straight across. This is used for CSS isolation, and plane splitting.
TileCache
Used to cache a picture as a series of tiles.
SVGFEGraph(Vec<(FilterGraphNode, FilterGraphOp)>)
Apply an SVG filter graph
IntermediateSurface
A surface that is used as an input to another primitive
Implementations
Sourceimpl PictureCompositeMode
impl PictureCompositeMode
pub fn get_rect( &self, surface: &SurfaceInfo, sub_rect: Option<LayoutRect>, ) -> LayoutRect
pub fn get_coverage( &self, surface: &SurfaceInfo, sub_rect: Option<LayoutRect>, ) -> LayoutRect
pub fn write_gpu_blocks( &self, surface: &SurfaceInfo, gpu_buffers: &mut GpuBufferBuilder, data_stores: &mut DataStores, extra_gpu_data: &mut SmallVec<[GpuBufferAddress; 1]>, )